@@ -67,8 +67,10 @@ def _filename_explode(x):
         if isinstance(x, pathlib.Path):
              x = str(x)
     parsed = urlparse(x)
-    if _bytesid(parsed.scheme) == b"file" or len(parsed.scheme) == 0 or (os.name == "nt" and open._windows_absolute.match(x) is not None):
-        pattern = os.path.expanduser(parsed.netloc + parsed.path)
+    if _bytesid(parsed.scheme) == b"file" or len(parsed.scheme) == 0 or (os.name == "nt" and _filename_explode._windows_absolute.match(x) is not None):
+        if not (os.name == "nt" and _filename_explode._windows_absolute.match(x) is not None):
+            path = parsed.netloc + parsed.path
+        pattern = os.path.expanduser(path)
         if "*" in pattern or "?" in pattern or "[" in pattern:
             out = sorted(glob.glob(pattern))
             if len(out) == 0:
@@ -111,8 +113,8 @@ def _normalize_entrystartstop(numentries, entrystart, entrystop):
 
 def iterate(path, treepath, branches=None, entrysteps=float("inf"), outputtype=dict, namedecode=None, reportpath=False, reportfile=False, reportentries=False, flatten=False, flatname=None, awkwardlib=None, cache=None, basketcache=None, keycache=None, executor=None, blocking=True, localsource=MemmapSource.defaults, xrootdsource=XRootDSource.defaults, httpsource=HTTPSource.defaults, **options):
     awkward = _normalize_awkwardlib(awkwardlib)
-    for tree, newbranches, globalentrystart, thispath, thisfile in _iterate(path, treepath, branches, awkward, localsource, xrootdsource, httpsource, **options):
-        for start, stop, arrays in tree.iterate(branches=newbranches, entrysteps=entrysteps, outputtype=outputtype, namedecode=namedecode, reportentries=True, entrystart=0, entrystop=tree.numentries, flatten=flatten, flatname=flatname, awkwardlib=awkward, cache=cache, basketcache=basketcache, keycache=keycache, executor=executor, blocking=blocking):
+    for tree, branchesinterp, globalentrystart, thispath, thisfile in _iterate(path, treepath, branches, awkward, localsource, xrootdsource, httpsource, **options):
+        for start, stop, arrays in tree.iterate(branches=branchesinterp, entrysteps=entrysteps, outputtype=outputtype, namedecode=namedecode, reportentries=True, entrystart=0, entrystop=tree.numentries, flatten=flatten, flatname=flatname, awkwardlib=awkward, cache=cache, basketcache=basketcache, keycache=keycache, executor=executor, blocking=blocking):
 
             if getattr(outputtype, "__name__", None) == "DataFrame" and getattr(outputtype, "__module__", None) == "pandas.core.frame":
                 if type(arrays.index).__name__ == "MultiIndex":
@@ -156,11 +158,6 @@ def _iterate(path, treepath, branches, awkward, localsource, xrootdsource, https
     else:
         paths = [y for x in path for y in _filename_explode(x)]
 
-    oldpath = None
-    oldbranches = None
-    holdover = None
-    holdoverentries = 0
-    outerstart = 0
     globalentrystart = 0
     for path in paths:
         file = uproot.rootio.open(path, localsource=localsource, xrootdsource=xrootdsource, httpsource=httpsource, **options)
@@ -168,22 +165,11 @@ def _iterate(path, treepath, branches, awkward, localsource, xrootdsource, https
             tree = file[treepath]
         except KeyError:
             continue
-        listbranches = list(tree._normalize_branches(branches, awkward))
+        branchesinterp = OrderedDict()
+        for branch, interpretation in tree._normalize_branches(branches, awkward):
+            branchesinterp[branch.name] = interpretation
 
-        newbranches = OrderedDict((branch.name, interpretation) for branch, interpretation in listbranches)
-        if oldbranches is not None:
-            for key in set(oldbranches.keys()).union(set(newbranches.keys())):
-                if key not in newbranches:
-                    raise ValueError("branch {0} cannot be found in {1}, but it was in {2}".format(repr(key), repr(path), repr(oldpath)))
-                if key not in oldbranches:
-                    del newbranches[key]
-                elif not newbranches[key].compatible(oldbranches[key]):
-                    raise ValueError("branch {0} interpreted as {1} in {2}, but as {3} in {4}".format(repr(key), newbranches[key], repr(path), oldbranches[key], repr(oldpath)))
-
-        oldpath = path
-        oldbranches = newbranches
-
-        yield tree, newbranches, globalentrystart, path, file
+        yield tree, branchesinterp, globalentrystart, path, file
         globalentrystart += tree.numentries
 
 ################################################################ methods for TTree
@@ -238,6 +224,7 @@ class TTreeMethods(object):
         branch._isTClonesArray = isTClonesArray
         if isinstance(streamer, uproot.rootio.TStreamerSTL) and streamer._fSTLtype == uproot.const.kSTLvector:
             branch._vecstreamer = streamerinfosmap.get(re.match(self._vector_regex, streamer._fTypeName).group(1), None)
+            isTClonesArray = True
         else:
             branch._vecstreamer = None
 
@@ -558,7 +545,7 @@ class TTreeMethods(object):
         else:
             return wait
 
-    def lazyarray(self, branch, interpretation=None, entrysteps=None, entrystart=None, entrystop=None, flatten=False, awkwardlib=None, cache=None, basketcache=None, keycache=None, executor=None, persistvirtual=False):
+    def lazyarray(self, branch, interpretation=None, entrysteps=None, entrystart=None, entrystop=None, flatten=False, awkwardlib=None, cache=None, basketcache=None, keycache=None, executor=None, persistvirtual=False, chunked=True):
         awkward = _normalize_awkwardlib(awkwardlib)
         branches = list(self._normalize_branches(branch, awkward))
         if len(branches) == 1:
@@ -568,10 +555,12 @@ class TTreeMethods(object):
                 tbranch, _ = branches[0]
         else:
             raise ValueError("list of branch names or glob/regex matches more than one branch; use TTree.lazyarrays (plural)")
-        return tbranch.lazyarray(interpretation=interpretation, entrysteps=entrysteps, entrystart=entrystart, entrystop=entrystop, flatten=flatten, awkwardlib=awkwardlib, cache=cache, basketcache=basketcache, keycache=keycache, executor=executor, persistvirtual=persistvirtual)
+        return tbranch.lazyarray(interpretation=interpretation, entrysteps=entrysteps, entrystart=entrystart, entrystop=entrystop, flatten=flatten, awkwardlib=awkwardlib, cache=cache, basketcache=basketcache, keycache=keycache, executor=executor, persistvirtual=persistvirtual, chunked=chunked)
 
-    def lazyarrays(self, branches=None, namedecode="utf-8", entrysteps=None, entrystart=None, entrystop=None, flatten=False, profile=None, awkwardlib=None, cache=None, basketcache=None, keycache=None, executor=None, persistvirtual=False):
+    def lazyarrays(self, branches=None, namedecode="utf-8", entrysteps=None, entrystart=None, entrystop=None, flatten=False, profile=None, awkwardlib=None, cache=None, basketcache=None, keycache=None, executor=None, persistvirtual=False, chunked=True):
         entrystart, entrystop = _normalize_entrystartstop(self.numentries, entrystart, entrystop)
+        if not chunked and entrysteps is None:
+            entrysteps = float('inf')
         entrysteps = list(self._normalize_entrysteps(entrysteps, branches, entrystart, entrystop, keycache))
         awkward = _normalize_awkwardlib(awkwardlib)
         branches = list(self._normalize_branches(branches, awkward))
@@ -593,13 +582,17 @@ class TTreeMethods(object):
             else:
                 VirtualArray = awkward.VirtualArray
 
-            chunks = []
-            counts = []
-            for start, stop in entrysteps:
-                chunks.append(VirtualArray(lazytree, (branch.name, start, stop), cache=cache, type=awkward.type.ArrayType(stop - start, interpretation.type), persistvirtual=persistvirtual))
-                counts.append(stop - start)
             name = branch.name.decode("ascii") if namedecode is None else branch.name.decode(namedecode)
-            out[name] = awkward.ChunkedArray(chunks, counts)
+            if chunked:
+                chunks = []
+                counts = []
+                for start, stop in entrysteps:
+                    chunks.append(VirtualArray(lazytree, (branch.name, start, stop), cache=cache, type=awkward.type.ArrayType(stop - start, interpretation.type), persistvirtual=persistvirtual))
+                    counts.append(stop - start)
+                out[name] = awkward.ChunkedArray(chunks, counts)
+            else:
+                start, stop = entrysteps[0]
+                out[name] = VirtualArray(lazytree, (branch.name, start, stop), cache=cache, type=awkward.type.ArrayType(stop - start, interpretation.type), persistvirtual=persistvirtual)
 
         if profile is not None:
             out = uproot_methods.profiles.transformer(profile)(out)
@@ -1590,7 +1583,7 @@ class TBranchMethods(object):
                 raise TypeError("entrysteps must be None for cluster iteration, a positive integer for equal steps in number of entries (inf for maximal), a memory size string (number followed by B/kB/MB/GB/etc.), or an iterable of 2-tuples for explicit entry starts (inclusive) and stops (exclusive)")
             return entrysteps
 
-    def lazyarray(self, interpretation=None, entrysteps=None, entrystart=None, entrystop=None, flatten=False, awkwardlib=None, cache=None, basketcache=None, keycache=None, executor=None, persistvirtual=False):
+    def lazyarray(self, interpretation=None, entrysteps=None, entrystart=None, entrystop=None, flatten=False, awkwardlib=None, cache=None, basketcache=None, keycache=None, executor=None, persistvirtual=False, chunked=True):
         if self._recoveredbaskets is None:
             self._tryrecover()
         awkward = _normalize_awkwardlib(awkwardlib)
@@ -1598,6 +1591,8 @@ class TBranchMethods(object):
         if interpretation is None:
             raise ValueError("cannot interpret branch {0} as a Python type\n   in file: {1}".format(repr(self.name), self._context.sourcepath))
         entrystart, entrystop = _normalize_entrystartstop(self.numentries, entrystart, entrystop)
+        if not chunked and entrysteps is None:
+            entrysteps = float('inf')
         entrysteps = self._normalize_entrysteps(entrysteps, entrystart, entrystop, keycache)
 
         inner = interpretation
@@ -1615,14 +1610,18 @@ class TBranchMethods(object):
 
         lazybranch = _LazyBranch(self._context.sourcepath, self._context.treename, self.name, self, interpretation, flatten, awkward.__name__, basketcache, keycache, executor)
 
-        chunks = []
-        counts = []
-        for start, stop in entrysteps:
-            numentries = stop - start
-            chunks.append(VirtualArray(lazybranch, (start, stop), cache=cache, type=awkward.type.ArrayType(numentries, interpretation.type), persistvirtual=persistvirtual))
-            counts.append(numentries)
+        if chunked:
+            chunks = []
+            counts = []
+            for start, stop in entrysteps:
+                numentries = stop - start
+                chunks.append(VirtualArray(lazybranch, (start, stop), cache=cache, type=awkward.type.ArrayType(numentries, interpretation.type), persistvirtual=persistvirtual))
+                counts.append(numentries)
 
-        return chunkedarray(chunks, counts)
+            return chunkedarray(chunks, counts)
+        else:
+            start, stop = entrysteps[0]
+            return VirtualArray(lazybranch, (start, stop), cache=cache, type=awkward.type.ArrayType(numentries, interpretation.type), persistvirtual=persistvirtual)
 
     class _BasketKey(object):
         def __init__(self, source, cursor, compression, complete):
